package com.jeeplus.modules.sg.balancedlibrary.transitMaterialGoods.util;

import com.jeeplus.modules.sg.balancedlibrary.materialQuota.entity.MaterialQuota;
import com.jeeplus.modules.sg.balancedlibrary.materialReportDetails.entity.MaterialReportDetails;
import com.jeeplus.modules.sg.balancedlibrary.standardMaterials.entity.StandardMaterials;
import com.jeeplus.modules.sg.balancedlibrary.transitMaterialGoods.entity.TransitMaterialGoods;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.xssf.usermodel.XSSFCellStyle;
import org.apache.poi.xssf.usermodel.XSSFFont;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import java.util.List;
import java.util.Map;

/**
 * 创建新的sheet
 * @author: 王强
 * @create: 2022-09-01 09:33
 **/
public class CreateSheetUtil {

    public void createSheet(String sheetName, String []title, String [][]values, XSSFWorkbook workbook,
                            List<MaterialReportDetails> reportList,
                            List<StandardMaterials> standardList, List<String> preferredCodes,
                            List<MaterialQuota> quotaList, List<TransitMaterialGoods> goodsList,
                            Map<String, String> reportPersonMap){

        //添加一个新的sheet
        Sheet sheet3 = workbook.createSheet(sheetName);
        //大标题样式
        XSSFCellStyle headStyle = workbook.createCellStyle();   //创建样式
        headStyle.setAlignment(HorizontalAlignment.CENTER);    //居中
        headStyle.setVerticalAlignment(VerticalAlignment.CENTER);
        Font titleFont = workbook.createFont(); //创建字体样式
        titleFont.setFontName("Arial");     //设置字体
        titleFont.setFontHeightInPoints((short)16); //字体大小
        titleFont.setBold(true);  //粗体
        headStyle.setFont(titleFont);

        //设置标题样式 -- title
        XSSFCellStyle cellStyle = workbook.createCellStyle();
        cellStyle.setAlignment(HorizontalAlignment.CENTER);
        cellStyle.setFillForegroundColor(IndexedColors.GREY_50_PERCENT.getIndex());     //背景颜色
        cellStyle.setFillPattern(FillPatternType.SOLID_FOREGROUND);

        cellStyle.setBorderBottom(BorderStyle.THIN);       //边框
        cellStyle.setBorderLeft(BorderStyle.THIN);
        cellStyle.setBorderTop(BorderStyle.THIN);
        cellStyle.setBorderRight(BorderStyle.THIN);

        XSSFFont font = workbook.createFont();
        font.setFontName("Arial");
        font.setFontHeightInPoints((short)12);
        font.setBold(true);
        font.setColor(IndexedColors.WHITE.getIndex());      //字体颜色
        cellStyle.setFont(font);

        //设置内容样式
        XSSFCellStyle contentStyle = workbook.createCellStyle();
        contentStyle.setAlignment(HorizontalAlignment.CENTER);
        contentStyle.setBorderBottom(BorderStyle.THIN);
        contentStyle.setBorderLeft(BorderStyle.THIN);
        contentStyle.setBorderTop(BorderStyle.THIN);
        contentStyle.setBorderRight(BorderStyle.THIN);

        XSSFFont contentFont = workbook.createFont();
        contentFont.setFontName("Calibri");
        contentFont.setFontHeightInPoints((short)11);
        contentFont.setColor(IndexedColors.BLACK.getIndex());   //字体颜色
        contentStyle.setFont(contentFont);
        contentStyle.setWrapText(true);     //设置单元格内容自动换行
        contentStyle.setAlignment(HorizontalAlignment.CENTER);    //居中
        contentStyle.setVerticalAlignment(VerticalAlignment.CENTER);

        //在sheet中添加表头第0行，
        Row row = sheet3.createRow(0);
        Cell cell = null;

        cell = row.createCell(0);
        cell.setCellValue("物料信息表");
        cell.setCellStyle(headStyle);

        //创建标题
        row = sheet3.createRow(1);
        for (int i=0;i<title.length;i++){
            cell = row.createCell(i);
            cell.setCellValue(title[i]);
            cell.setCellStyle(cellStyle);
        }

        //创建内容
        for (int i=0;i<values.length;i++){
            row = sheet3.createRow(i+2);
            for (int j=0;j<values[i].length;j++){
                //将内容按顺序赋给对应的列对象
                Cell cell1 = row.createCell(j);
                cell1.setCellValue(values[i][j]);
                cell1.setCellStyle(contentStyle);
            }
        }
        //大标题合并居中
        CellRangeAddress region = new CellRangeAddress(0,0,0,title.length-1);   //大标题合并居中
        sheet3.addMergedRegion(region);
        //设置行宽
        for (int i=0;i<title.length;i++) {
            sheet3.setColumnWidth(i, 4000);
        }
    }
}
